@@ -338,7 +338,6 @@ Application::Application ():
 		/* get the theme style for labels so that tools buttons colors might
 		be adapted to the current theme */
 		GtkWidget *w=gtk_label_new("");
-		GtkSettings *st = gtk_settings_get_default();
 		m_Style = gtk_rc_get_style(w);
 		gtk_widget_destroy (w);
 
@@ -1008,8 +1007,22 @@ static void on_tool_changed (GtkAction *action, GtkAction *current, Application*
 
 void Application::OnToolChanged (GtkAction *current)
 {
-	if (m_pActiveTool)
-		m_pActiveTool->Activate(false);
+	char const *name = gtk_action_get_name (current);
+	if (m_pActiveTool) {
+		if (m_pActiveTool->GetName () == name)
+			return;
+		if (!m_pActiveTool->Activate(false)) {
+			GSList *list = gtk_radio_action_get_group (GTK_RADIO_ACTION (current));
+			while (list) {
+				if (m_pActiveTool->GetName () == gtk_action_get_name ((GtkAction *) list->data)) {
+					gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (list->data), true);
+					break;
+				}
+				list = list->next;
+			}
+			return;
+		}
+	}
 	m_pActiveTool = m_Tools[gtk_action_get_name (current)];
 	Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
 	if (ToolsBox)
@@ -1018,7 +1031,7 @@ void Application::OnToolChanged (GtkAction *current)
 		m_pActiveTool->Activate(true);
 }
 
-void Application::BuildTools ()
+void Application::BuildTools () throw (std::runtime_error)
 {
 	Tools *ToolsBox = new Tools (this);
 	map<int, string>::iterator i, iend = ToolbarNames.end ();
@@ -1033,9 +1046,9 @@ void Application::BuildTools ()
 	gtk_ui_manager_insert_action_group (ToolsManager, action_group, 0);
 	for (j = UiDescs.begin (); j != jend; j++)
 		if (!gtk_ui_manager_add_ui_from_string (ToolsManager, *j, -1, &error)) {
-			g_message ("building user interface failed: %s", error->message);
+			string what = string ("building user interface failed: ") + error->message;
 			g_error_free (error);
-			exit (EXIT_FAILURE);
+			throw runtime_error (what);
 		}
 	for (i = ToolbarNames.begin (); i != iend; i++) {
 		s = "ui/";
