@@ -158,16 +158,33 @@ bool Bond::GetLine2DCoords (unsigned Num, double* x1, double* y1, double* x2, do
 			}
 		} else if ((m_order == 2) && IsCyclic ()) {
 			Cycle* pCycle;
+			double a0 = atan2 (*y1 - *y2, *x2 - *x1), a1, a2;
 			if (IsCyclic() > 1) {
 				//Search prefered cycle
 				list<Cycle*>::iterator i = m_Cycles.begin (), end = m_Cycles.end ();
 				pCycle = *i;
-				for (; i != end; i++)
-					if (pCycle->IsBetterForBonds (*i))
+				pCycle->GetAngles2D (this, &a1, &a2);
+				bool trans = sin(a0 - a1) * sin (a0 - a2) <= 0; // we prefer a cycle with cis configuration
+				for (; i != end; i++) {
+					if (trans) {
+						(*i)->GetAngles2D (this, &a1, &a2);
+						if (sin(a0 - a1) * sin (a0 - a2) > 0) {
+							trans = false;
+							pCycle = *i;
+							continue;
+						}
+					}
+					if (pCycle->IsBetterForBonds (*i)) {
+						if (!trans) {
+							(*i)->GetAngles2D (this, &a1, &a2);
+							if (sin(a0 - a1) * sin (a0 - a2) <= 0)
+								continue;
+						}
 						pCycle = *i;
+					}
+				}
 			} else
 				pCycle = m_Cycles.front();
-			double a0 = atan2 (*y1 - *y2, *x2 - *x1), a1, a2;
 			pCycle->GetAngles2D (this, &a1, &a2);
 			if (sin(a0 - a1) * sin (a0 - a2) > 0) {
 				double sign = sin (a0 - a1) > 0.0 ? 1.0 : -1.0;
@@ -211,8 +228,8 @@ general:
 							}
 							bond = reinterpret_cast <Bond*> (m_End->GetNextBond (it));
 						}
-					m_coords[6] = *x2 - BondDist * cosa * tanb - dy * sign;
-					m_coords[7] = *y2 + dx * sign + BondDist * sina * tanb;
+					m_coords[6] = *x2 + BondDist * cosa * tanb - dy * sign;
+					m_coords[7] = *y2 + dx * sign - BondDist * sina * tanb;
 					goto done;
 				}
 			} else if (n1 > 1 && n2 > 0) {
@@ -239,8 +256,8 @@ general:
 								}
 								bond = reinterpret_cast <Bond*> (m_Begin->GetNextBond (it));
 							}
-						m_coords[4] = *x1 + BondDist * cosa * tanb - dy * sign;
-						m_coords[5] = *y1 + dx * sign - BondDist * sina * tanb;
+						m_coords[4] = *x1 - BondDist * cosa * tanb - dy * sign;
+						m_coords[5] = *y1 + dx * sign + BondDist * sina * tanb;
 						tanb = (m_End->GetZ () == 6)? fabs (tan ((a1 - a0) / 2)): 0.;
 						m_coords[6] = *x2 - BondDist * cosa * tanb - dy * sign;
 						m_coords[7] = *y2 + dx * sign + BondDist * sina * tanb;
@@ -883,9 +900,11 @@ void Bond::Update(GtkWidget* w) const
 	}
 	path = const_cast <Bond *> (this)->BuildPathDef (pData);
 	obj = g_object_get_data(G_OBJECT(group), "path");
-	g_object_set (obj, "bpath", path, NULL);
-	if (m_type == NormalBondType || m_type == UndeterminedBondType)
-		g_object_set (obj, "width_units", pTheme->GetBondWidth (), NULL);
+	if (obj) {
+		g_object_set (obj, "bpath", path, NULL);
+		if (m_type == NormalBondType || m_type == UndeterminedBondType)
+			g_object_set (obj, "width_units", pTheme->GetBondWidth (), NULL);
+	}
 	gnome_canvas_path_def_unref (path);
 }
 	
