@@ -114,7 +114,9 @@ bool StringDlg::Apply ()
 		err = g_file_query_exists (file, NULL);
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
-			gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename2);
+			char *unescaped = g_uri_unescape_string (filename2, NULL);
+			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
+			g_free (unescaped);
 			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 			result = gtk_dialog_run (Box);
@@ -128,7 +130,9 @@ bool StringDlg::Apply ()
 			if (err) {
 				g_file_delete (file, NULL, &error);
 				if (error) {
-					gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), filename2, error->message);
+					char *unescaped = g_uri_unescape_string (filename2, NULL);
+					gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), unescaped, error->message);
+					g_free (unescaped);
 					g_error_free (error);
 					GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 					gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
@@ -142,7 +146,9 @@ bool StringDlg::Apply ()
 			ostringstream ofs;
 			GOutputStream *output = G_OUTPUT_STREAM (g_file_create (file, G_FILE_CREATE_NONE, NULL, &error));
 			if (error) {
-				gchar * message = g_strdup_printf (_("Could not open file %s, error was:\n%s"), filename2, error->message);
+				char *unescaped = g_uri_unescape_string (filename2, NULL);
+				gchar * message = g_strdup_printf (_("Could not open file %s, error was:\n%s"), unescaped, error->message);
+				g_free (unescaped);
 				GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message));
 				gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 				gtk_dialog_run (Box);
@@ -158,7 +164,9 @@ bool StringDlg::Apply ()
 			while (n < nb) {
 				n += g_output_stream_write (output, ofs.str ().c_str () + n, nb - n, NULL, &error);
 				if (error) {
-					gchar * message = g_strdup_printf (_("Could not write to file %s, error was:\n%s."), filename2, error->message);
+					char *unescaped = g_uri_unescape_string (filename2, NULL);
+					gchar * message = g_strdup_printf (_("Could not write to file %s, error was:\n%s."), unescaped, error->message);
+					g_free (unescaped);
 					GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message));
 					gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 					gtk_dialog_run (Box);
@@ -172,7 +180,9 @@ bool StringDlg::Apply ()
 			g_output_stream_close (output, NULL, &error);
 			g_object_unref (file);
 			if (error) {
-				gchar * message = g_strdup_printf (_("Could not close file %s, error was:\n%s"), filename2, error->message);
+				char *unescaped = g_uri_unescape_string (filename2, NULL);
+				gchar * message = g_strdup_printf (_("Could not close file %s, error was:\n%s"), unescaped, error->message);
+				g_free (unescaped);
 				GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message));
 				gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 				gtk_dialog_run (Box);
