@@ -228,7 +228,9 @@ bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool
 		bool err = g_file_query_exists (file, NULL);
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
-			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), filename);
+			char *unescaped = g_uri_unescape_string (filename, NULL);
+			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
+			g_free (unescaped);
 			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gspectrum");
 			result = gtk_dialog_run (Box);
@@ -262,7 +264,7 @@ GChemCalc *App;
 
 static void on_quit (GtkWidget *widget, void *data)
 {
-	gtk_main_quit();
+	gtk_widget_destroy (GTK_WIDGET (App->window));
 }
 
 static void on_help (GtkWidget *widget, gpointer data)
@@ -792,11 +794,7 @@ int main (int argc, char *argv[])
 	App->mono = GTK_LABEL (glade_xml_get_widget (xml, "mono"));
 	App->monomass = GTK_LABEL (glade_xml_get_widget (xml, "monomass"));
 	App->pattern_page = glade_xml_get_widget (xml, "pattern");
-#ifdef GO_GRAPH_WIDGET_OLD_API
-	App->graph_widget = go_graph_widget_new ();
-#else
 	App->graph_widget = go_graph_widget_new (NULL);
-#endif
 	gtk_widget_show (App->graph_widget);
 	gtk_box_pack_end (GTK_BOX (App->pattern_page), App->graph_widget, TRUE, TRUE, 0);
 	App->graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (App->graph_widget));
