@@ -4,7 +4,7 @@
  * Gnome Crystal
  * main.cc 
  *
- * Copyright (C) 2000-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -33,8 +33,9 @@
 #include "view.h"
 #include "globals.h"
 #include <goffice/utils/go-file.h>
-#include <libgnomevfs/gnome-vfs-init.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#ifdef GOFFICE_IS_0_6
+#	include <libgnomevfs/gnome-vfs-init.h>
+#endif
 #include <gtk/gtkglinit.h>
 #include <glib/gi18n.h>
 #include <cstdio>
@@ -105,7 +106,9 @@ int main(int argc, char *argv[])
 
 	gtk_init (&argc, &argv);
 	gtk_gl_init (&argc, &argv);
+#ifdef GOFFICE_IS_0_6
 	gnome_vfs_init ();
+#endif
 	Element::LoadRadii ();
 	if (argc > 1 && argv[1][0] == '-') {
 		context = g_option_context_new (_(" [file...]"));
@@ -149,31 +152,27 @@ int main(int argc, char *argv[])
 	gcDocument *pDoc = gcApp->OnFileNew();
 	gcApp->SetOpening();
 
-	GnomeVFSURI *uri, *auri;
-	char *path = g_get_current_dir (), *dir;
-	dir = g_strconcat (path, "/", NULL);
-	g_free (path);
-	uri = gnome_vfs_uri_new (dir);
+	char *path, *uri;
 	bool bres = false;
 	while (*argv) {
 		if (**argv == '-') {
 			printf (_("Invalid or misplaced argument: %s\n"), *argv);
 			delete gcApp;
-			g_free (dir);
-			gnome_vfs_uri_unref (uri);
 			exit (-1);
 		}
-		auri = gnome_vfs_uri_resolve_relative (uri, *argv);
-		path = gnome_vfs_uri_to_string (auri, GNOME_VFS_URI_HIDE_NONE);
+		if (strstr (*argv, "://"))
+			uri = g_strdup (*argv);
+		else {
+			path = g_path_is_absolute (*argv)? g_strdup (*argv): g_build_filename (g_get_current_dir (), *argv, NULL);
+			uri = g_filename_to_uri (path, NULL, NULL);
+			g_free (path);
+		}
 		if (bres)
 			pDoc = gcApp->OnFileNew ();
-		bres = gcApp->FileProcess (path, go_get_mime_type (path), false, NULL, pDoc);
-		g_free (path);
-		gnome_vfs_uri_unref (auri);
+		bres = gcApp->FileProcess (uri, go_get_mime_type (uri), false, NULL, pDoc);
+		g_free (uri);
 		argv++;
 	}
-	gnome_vfs_uri_unref (uri);
-	g_free (dir);
 	gtk_main ();
 
 #ifdef HAVE_GO_CONF_SYNC
@@ -187,7 +186,8 @@ int main(int argc, char *argv[])
 	g_object_unref (G_OBJECT(conf_client));
 #endif
 
+#ifdef GOFFICE_IS_0_6
 	gnome_vfs_shutdown ();
-
+#endif
 	return 0 ;
 }
