@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -49,6 +49,7 @@
 #include <goffice/utils/go-marker.h>
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
+#include <gsf/gsf-output-gio.h>
 #include <glib/gi18n.h>
 #include <map>
 #include <cstring>
@@ -148,6 +149,11 @@ static void on_copy (GtkWidget *widget, GChemTableCurve *curve)
 	curve->OnCopy ();
 }
 
+static void on_file_save_as_image(GtkWidget* widget, GChemTableCurve *curve)
+{
+	curve->GetApplication ()->OnSaveAsImage (curve);
+}
+
 static void on_print (GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->Print (false);
@@ -210,6 +216,8 @@ static void on_about (GtkWidget *widget, GChemTableCurve *curve)
 
 static GtkActionEntry entries[] = {
   { "FileMenu", NULL, N_("_File") },
+	  { "SaveAsImage", GTK_STOCK_SAVE_AS, N_("Save As _Image..."), "<control>I",
+		  N_("Save the current file as an image"), G_CALLBACK (on_file_save_as_image) },
 	  { "PageSetup", NULL, N_("Page Set_up..."), NULL,
 		  N_("Setup the page settings for your current printer"), G_CALLBACK (on_page_setup) },
 	  { "PrintPreview", GTK_STOCK_PRINT_PREVIEW, N_("Print Pre_view"), NULL,
@@ -246,6 +254,8 @@ static const char *ui_description =
 "<ui>"
 "  <menubar name='MainMenu'>"
 "    <menu action='FileMenu'>"
+"      <menuitem action='SaveAsImage'/>"
+"		<separator/>"
 "      <menuitem action='PageSetup'/>"
 "      <menuitem action='PrintPreview'/>"
 "      <menuitem action='Print'/>"
@@ -595,3 +605,20 @@ void GChemTableCurve::SetGraph (GogGraph *graph)
 	m_Graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (m_GraphWidget));
 }
 
+void GChemTableCurve::SaveAsImage (string const &filename, char const *mime_type, unsigned width, unsigned height) const
+{
+	char *fname = go_mime_to_image_format (mime_type);
+	GOImageFormat format = go_image_get_format_from_name ((fname)? fname: filename.c_str ());
+	if (format == GO_IMAGE_FORMAT_UNKNOWN)
+		return;
+	GError *error = NULL;
+	GsfOutput *output = gsf_output_gio_new_for_uri (filename.c_str (), &error);
+	if (error) {
+		g_error_free (error);
+		return;
+	}
+	GogGraph *graph = gog_graph_dup (m_Graph);
+	gog_graph_set_size (graph, width, height);
+	gog_graph_export_image (graph, format, output, -1., -1.);
+	g_object_unref (graph);
+}
