@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -167,13 +167,17 @@ gct_data_vector_load_values (GODataVector *dat)
 	vec->loaded = true;
 	dat->values = vec->data;
 	if (dat->len > 0) {
-		dat->minimum = dat->maximum = vec->data[0];
-		for (int i = 1; i < dat->len; i++) {
-			if (vec->data[i] < dat->minimum)
-				dat->minimum = vec->data[i];
-			if (vec->data[i] > dat->maximum)
-				dat->maximum = vec->data[i];
-		}
+		int i = 0;
+		while (!go_finite (vec->data[i++]) && i < dat->len);
+		if (i < dat->len)
+			dat->minimum = dat->maximum = vec->data[i];
+		for (; i < dat->len; i++)
+			if (go_finite (vec->data[i])) {
+				if (vec->data[i] < dat->minimum)
+					dat->minimum = vec->data[i];
+				if (vec->data[i] > dat->maximum)
+					dat->maximum = vec->data[i];
+			}
 	}
 	dat->base.flags |= GO_DATA_CACHE_IS_VALID;
 }
